[Libreoffice-commits] .: chart2/source sc/inc sc/qa sc/source

Caolán McNamara caolan at kemper.freedesktop.org
Mon Dec 6 01:16:59 PST 2010


 chart2/source/inc/DiagramHelper.hxx                             |    2 
 chart2/source/tools/XMLRangeHelper.cxx                          |    2 
 sc/inc/autonamecache.hxx                                        |    2 
 sc/inc/dociter.hxx                                              |    4 
 sc/inc/document.hxx                                             |    2 
 sc/qa/complex/dataPilot/interfaceTests/beans/_XPropertySet.java |   44 +++++-----
 sc/qa/complex/sc/CalcRTL.java                                   |    2 
 sc/source/core/data/autonamecache.cxx                           |    2 
 sc/source/core/data/dociter.cxx                                 |    4 
 sc/source/core/data/dpobject.cxx                                |    2 
 sc/source/core/data/validat.cxx                                 |    2 
 sc/source/core/tool/compiler.cxx                                |    4 
 sc/source/core/tool/interpr5.cxx                                |    2 
 sc/source/filter/excel/xepivot.cxx                              |    2 
 sc/source/filter/inc/fapihelper.hxx                             |    2 
 sc/source/filter/inc/xehelper.hxx                               |    2 
 sc/source/filter/inc/xistyle.hxx                                |    4 
 sc/source/ui/app/scmod.cxx                                      |    2 
 sc/source/ui/miscdlgs/linkarea.cxx                              |    2 
 sc/source/ui/unoobj/dapiuno.cxx                                 |    4 
 sc/source/ui/unoobj/nameuno.cxx                                 |    2 
 sc/source/ui/unoobj/viewuno.cxx                                 |   12 +-
 22 files changed, 53 insertions(+), 53 deletions(-)

New commits:
commit 6689a8040414a4350198e134d2b71a199e946961
Author: Takeshi Abe <tabe at fixedpoint.jp>
Date:   Sat Dec 4 12:51:48 2010 +0900

    Replace all occured, occurance etc.

diff --git a/chart2/source/inc/DiagramHelper.hxx b/chart2/source/inc/DiagramHelper.hxx
index 1931ec8..aae2c0f 100644
--- a/chart2/source/inc/DiagramHelper.hxx
+++ b/chart2/source/inc/DiagramHelper.hxx
@@ -159,7 +159,7 @@ public:
             ::com::sun::star::chart2::XDiagram > & xDiagram,
         sal_Int32 nNewDimensionCount );
 
-    /** Replaces all occurences of xCooSysToReplace in the tree with
+    /** Replaces all occurrences of xCooSysToReplace in the tree with
         xReplacement in the diagram's tree
      */
     SAL_DLLPRIVATE static void replaceCoordinateSystem(
diff --git a/chart2/source/tools/XMLRangeHelper.cxx b/chart2/source/tools/XMLRangeHelper.cxx
index b6b6801..9ecca60 100644
--- a/chart2/source/tools/XMLRangeHelper.cxx
+++ b/chart2/source/tools/XMLRangeHelper.cxx
@@ -358,7 +358,7 @@ CellRange getCellRangeFromXMLString( const OUString & rXMLString )
                 nStartPos, nEndPos - 1,
                 aResult ))
         {
-            // if an error occured, bail out
+            // if an error occurred, bail out
             return CellRange();
         }
     }
diff --git a/sc/inc/autonamecache.hxx b/sc/inc/autonamecache.hxx
index 3f1180c..e01a3f9 100644
--- a/sc/inc/autonamecache.hxx
+++ b/sc/inc/autonamecache.hxx
@@ -52,7 +52,7 @@ public:
             ScAutoNameCache( ScDocument* pD );
             ~ScAutoNameCache();
 
-    const ScAutoNameAddresses& GetNameOccurences( const String& rName, SCTAB nTab );
+    const ScAutoNameAddresses& GetNameOccurrences( const String& rName, SCTAB nTab );
 };
 
 #endif
diff --git a/sc/inc/dociter.hxx b/sc/inc/dociter.hxx
index 6bf0664..0c1b06a 100644
--- a/sc/inc/dociter.hxx
+++ b/sc/inc/dociter.hxx
@@ -256,8 +256,8 @@ class ScQueryCellIterator           // alle nichtleeren Zellen in einem Bereich
     {
         nStopOnMismatchDisabled = 0x00,
         nStopOnMismatchEnabled  = 0x01,
-        nStopOnMismatchOccured  = 0x02,
-        nStopOnMismatchExecuted = nStopOnMismatchEnabled | nStopOnMismatchOccured
+        nStopOnMismatchOccurred  = 0x02,
+        nStopOnMismatchExecuted = nStopOnMismatchEnabled | nStopOnMismatchOccurred
     };
 
     enum TestEqualConditionBits
diff --git a/sc/inc/document.hxx b/sc/inc/document.hxx
index c9bc655..0a0f4e2 100644
--- a/sc/inc/document.hxx
+++ b/sc/inc/document.hxx
@@ -680,7 +680,7 @@ public:
 
     /** Tries to find a DDE link or creates a new, if not extant.
         @param pResults  If not 0, sets the matrix as as DDE link result matrix (also for existing links).
-        @return  true = DDE link found; false = Unpredictable error occured, no DDE link created. */
+        @return  true = DDE link found; false = Unpredictable error occurred, no DDE link created. */
     SC_DLLPUBLIC bool            CreateDdeLink( const String& rAppl, const String& rTopic, const String& rItem, BYTE nMode, ScMatrix* pResults = NULL );
     /** Sets a result matrix for the specified DDE link.
         @param nDdePos  Index of the DDE link (does not include other links from link manager).
diff --git a/sc/qa/complex/dataPilot/interfaceTests/beans/_XPropertySet.java b/sc/qa/complex/dataPilot/interfaceTests/beans/_XPropertySet.java
index 09e4d7e..41ad527 100644
--- a/sc/qa/complex/dataPilot/interfaceTests/beans/_XPropertySet.java
+++ b/sc/qa/complex/dataPilot/interfaceTests/beans/_XPropertySet.java
@@ -205,19 +205,19 @@ public class _XPropertySet {
                 oObj.setPropertyValue(PTT.bound,
                     ValueChanger.changePValue(gValue));
             } catch (com.sun.star.beans.PropertyVetoException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.bound+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } catch (com.sun.star.lang.IllegalArgumentException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.bound+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } catch (com.sun.star.beans.UnknownPropertyException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.bound+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } catch (com.sun.star.lang.WrappedTargetException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.bound+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } // end of try-catch
@@ -260,19 +260,19 @@ public class _XPropertySet {
                 oObj.setPropertyValue(PTT.constrained,
                     ValueChanger.changePValue(gValue));
             } catch (com.sun.star.beans.PropertyVetoException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.constrained+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } catch (com.sun.star.lang.IllegalArgumentException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.constrained+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } catch (com.sun.star.beans.UnknownPropertyException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.constrained+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } catch (com.sun.star.lang.WrappedTargetException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.constrained+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } // end of try-catch
@@ -318,19 +318,19 @@ public class _XPropertySet {
                 oObj.setPropertyValue(PTT.normal, sValue);
                 sValue = oObj.getPropertyValue(PTT.normal);
             } catch (com.sun.star.beans.PropertyVetoException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.normal+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } catch (com.sun.star.lang.IllegalArgumentException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.normal+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } catch (com.sun.star.beans.UnknownPropertyException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.normal+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } catch (com.sun.star.lang.WrappedTargetException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.normal+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } // end of try-catch
@@ -368,12 +368,12 @@ public class _XPropertySet {
         try {
             Object gValue = oObj.getPropertyValue(toCheck);
         } catch (com.sun.star.beans.UnknownPropertyException e) {
-            log.println("Exception occured while trying to get property '"+
+            log.println("Exception occurred while trying to get property '"+
                  PTT.normal+"'");
             e.printStackTrace((java.io.PrintWriter)log);
             result = false;
         } catch (com.sun.star.lang.WrappedTargetException e) {
-            log.println("Exception occured while trying to get property '"+
+            log.println("Exception occurred while trying to get property '"+
                 PTT.normal+"'");
             e.printStackTrace((java.io.PrintWriter)log);
             result = false;
@@ -411,19 +411,19 @@ public class _XPropertySet {
                 oObj.setPropertyValue(PTT.bound,
                     ValueChanger.changePValue(gValue));
             } catch (com.sun.star.beans.PropertyVetoException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.bound+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } catch (com.sun.star.lang.IllegalArgumentException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.bound+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } catch (com.sun.star.beans.UnknownPropertyException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.bound+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } catch (com.sun.star.lang.WrappedTargetException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.bound+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } // end of try-catch
@@ -468,19 +468,19 @@ public class _XPropertySet {
                 oObj.setPropertyValue(PTT.constrained,
                     ValueChanger.changePValue(gValue));
             } catch (com.sun.star.beans.PropertyVetoException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.constrained+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } catch (com.sun.star.lang.IllegalArgumentException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.constrained+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } catch (com.sun.star.beans.UnknownPropertyException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.constrained+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } catch (com.sun.star.lang.WrappedTargetException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+ PTT.constrained+"'");
                 e.printStackTrace((java.io.PrintWriter)log);
             } // end of try-catch
diff --git a/sc/qa/complex/sc/CalcRTL.java b/sc/qa/complex/sc/CalcRTL.java
index fb39b7c..44e1ebe 100644
--- a/sc/qa/complex/sc/CalcRTL.java
+++ b/sc/qa/complex/sc/CalcRTL.java
@@ -325,7 +325,7 @@ public class CalcRTL extends ComplexTestCase {
             worked = checkResult(set, pName, oldValue, pValue, resValue, 
                                  exception);
         } catch (Exception e) {
-            System.out.println("Exception occured while testing property '" + 
+            System.out.println("Exception occurred while testing property '" + 
                                pName + "'");
             e.printStackTrace();
             worked = false;
diff --git a/sc/source/core/data/autonamecache.cxx b/sc/source/core/data/autonamecache.cxx
index 5ca9813..f137043 100644
--- a/sc/source/core/data/autonamecache.cxx
+++ b/sc/source/core/data/autonamecache.cxx
@@ -52,7 +52,7 @@ ScAutoNameCache::~ScAutoNameCache()
 {
 }
 
-const ScAutoNameAddresses& ScAutoNameCache::GetNameOccurences( const String& rName, SCTAB nTab )
+const ScAutoNameAddresses& ScAutoNameCache::GetNameOccurrences( const String& rName, SCTAB nTab )
 {
     if ( nTab != nCurrentTab )
     {
diff --git a/sc/source/core/data/dociter.cxx b/sc/source/core/data/dociter.cxx
index b7d52cd..0ba6a58 100644
--- a/sc/source/core/data/dociter.cxx
+++ b/sc/source/core/data/dociter.cxx
@@ -1169,7 +1169,7 @@ ScBaseCell* ScQueryCellIterator::GetThis()
                     if ( nTestEqualCondition && bTestEqualCondition )
                     {
                         nTestEqualCondition |= nTestEqualConditionMatched;
-                        nStopOnMismatch |= nStopOnMismatchOccured;
+                        nStopOnMismatch |= nStopOnMismatchOccurred;
                         return NULL;
                     }
                     bool bStop;
@@ -1187,7 +1187,7 @@ ScBaseCell* ScQueryCellIterator::GetThis()
                         bStop = true;
                     if (bStop)
                     {
-                        nStopOnMismatch |= nStopOnMismatchOccured;
+                        nStopOnMismatch |= nStopOnMismatchOccurred;
                         return NULL;
                     }
                 }
diff --git a/sc/source/core/data/dpobject.cxx b/sc/source/core/data/dpobject.cxx
index a3ff5ac..d6be537 100644
--- a/sc/source/core/data/dpobject.cxx
+++ b/sc/source/core/data/dpobject.cxx
@@ -1722,7 +1722,7 @@ SCSIZE lcl_FillOldFields( PivotField* pFields,
 
     SCSIZE nCount = (nOrient == sheet::DataPilotFieldOrientation_PAGE) ? PIVOT_MAXPAGEFIELD : PIVOT_MAXFIELD;
 
-    //!	merge multiple occurences (data field with different functions)
+    //!	merge multiple occurrences (data field with different functions)
     //!	force data field in one dimension
 
     std::vector< long > aPos( nCount, 0 );
diff --git a/sc/source/core/data/validat.cxx b/sc/source/core/data/validat.cxx
index cf79251..ef2a744 100644
--- a/sc/source/core/data/validat.cxx
+++ b/sc/source/core/data/validat.cxx
@@ -645,7 +645,7 @@ bool ScValidationData::GetSelectionFromFormula( TypedScStrCollection* pStrings,
     const ScMatrix *pValues = aValidationSrc.GetMatrix();
     if (!pValues)
     {
-        // The somewhat nasty case of either an error occured, or the
+        // The somewhat nasty case of either an error occurred, or the
         // dereferenced value of a single cell reference or an immediate result
         // is stored as a single value.
 
diff --git a/sc/source/core/tool/interpr5.cxx b/sc/source/core/tool/interpr5.cxx
index fe64d84..0ca178f 100644
--- a/sc/source/core/tool/interpr5.cxx
+++ b/sc/source/core/tool/interpr5.cxx
@@ -697,7 +697,7 @@ void ScInterpreter::MEMat(ScMatrix* mM, SCSIZE n)
  * permutations (row exchanges).
  *
  * Returns 0 if a singular matrix is encountered, else +1 if an even number of
- * permutations occured, or -1 if odd, which is the sign of the determinant.
+ * permutations occurred, or -1 if odd, which is the sign of the determinant.
  * This may be used to calculate the determinant by multiplying the sign with
  * the product of the diagonal elements of the LU matrix.
  */
diff --git a/sc/source/filter/excel/xepivot.cxx b/sc/source/filter/excel/xepivot.cxx
index ae4ca1d..c7b3d18 100644
--- a/sc/source/filter/excel/xepivot.cxx
+++ b/sc/source/filter/excel/xepivot.cxx
@@ -77,7 +77,7 @@ using ::rtl::OUStringBuffer;
 
 namespace {
 
-// constants to track occurence of specific data types
+// constants to track occurrence of specific data types
 const sal_uInt16 EXC_PCITEM_DATA_STRING     = 0x0001;   /// String, empty, boolean, error.
 const sal_uInt16 EXC_PCITEM_DATA_DOUBLE     = 0x0002;   /// Double with fraction.
 const sal_uInt16 EXC_PCITEM_DATA_INTEGER    = 0x0004;   /// Integer, double without fraction.
diff --git a/sc/source/filter/inc/fapihelper.hxx b/sc/source/filter/inc/fapihelper.hxx
index e1ddd85..2fe6c98 100644
--- a/sc/source/filter/inc/fapihelper.hxx
+++ b/sc/source/filter/inc/fapihelper.hxx
@@ -183,7 +183,7 @@ public:
                             { UnoAny aAny; return GetAnyProperty( aAny, rPropName ) && (aAny >>= rValue); }
 
     /** Gets the specified Boolean property from the property set.
-        @return  true = property contains true; false = property contains false or error occured. */
+        @return  true = property contains true; false = property contains false or error occurred. */
     bool                GetBoolProperty( const ::rtl::OUString& rPropName ) const;
 
     /** Gets the specified Boolean property from the property set.
diff --git a/sc/source/filter/inc/xehelper.hxx b/sc/source/filter/inc/xehelper.hxx
index db556b3..f02e8ad 100644
--- a/sc/source/filter/inc/xehelper.hxx
+++ b/sc/source/filter/inc/xehelper.hxx
@@ -177,7 +177,7 @@ class XclExpHyperlink;
 /** Helper to create HLINK records during creation of formatted cell strings.
 
     In Excel it is not possible to have more than one hyperlink in a cell. This
-    helper detects multiple occurences of hyperlinks and fills a string which
+    helper detects multiple occurrences of hyperlinks and fills a string which
     is used to create a cell note containing all URLs. Only cells containing
     one hyperlink are exported as hyperlink cells.
  */
diff --git a/sc/source/filter/inc/xistyle.hxx b/sc/source/filter/inc/xistyle.hxx
index 234ef29..5b16cc7 100644
--- a/sc/source/filter/inc/xistyle.hxx
+++ b/sc/source/filter/inc/xistyle.hxx
@@ -216,7 +216,7 @@ private:
 
 // FORMAT record - number formats =============================================
 
-/** Stores all user defined number formats occured in the file. */
+/** Stores all user defined number formats occurred in the file. */
 class XclImpNumFmtBuffer : public XclNumFmtBuffer, protected XclImpRoot
 {
 public:
@@ -480,7 +480,7 @@ private:
 
 // ----------------------------------------------------------------------------
 
-/** Contains all XF records occured in the file.
+/** Contains all XF records occurred in the file.
     @descr  This class is able to read XF records (BIFF2 - BIFF8) and STYLE records (BIFF8). */
 class XclImpXFBuffer : protected XclImpRoot, private boost::noncopyable
 {
diff --git a/sc/source/ui/app/scmod.cxx b/sc/source/ui/app/scmod.cxx
index 1bc98b5..2666bcc 100644
--- a/sc/source/ui/app/scmod.cxx
+++ b/sc/source/ui/app/scmod.cxx
@@ -1918,7 +1918,7 @@ IMPL_LINK( ScModule, IdleHandler, Timer*, EMPTYARG )
 
         bMore = bLinks || bWidth || bSpell;			// ueberhaupt noch was?
 
-        //	While calculating a Basic formula, a paint event may have occured,
+        //	While calculating a Basic formula, a paint event may have occurred,
         //	so check the bNeedsRepaint flags for this document's views
         if (bWidth)
             lcl_CheckNeedsRepaint( pDocSh );
diff --git a/sc/source/ui/miscdlgs/linkarea.cxx b/sc/source/ui/miscdlgs/linkarea.cxx
index 934ac66..4be8513 100644
--- a/sc/source/ui/miscdlgs/linkarea.cxx
+++ b/sc/source/ui/miscdlgs/linkarea.cxx
@@ -132,7 +132,7 @@ IMPL_LINK( ScLinkedAreaDlg, FileHdl, ComboBox*, EMPTYARG )
     String aFilter;
     String aOptions;
     //	get filter name by looking at the file content (bWithContent = TRUE)
-    // Break operation if any error occured inside.
+    // Break operation if any error occurred inside.
     if (!ScDocumentLoader::GetFilterName( aEntered, aFilter, aOptions, TRUE, TRUE ))
         return 0;
 
diff --git a/sc/source/ui/unoobj/dapiuno.cxx b/sc/source/ui/unoobj/dapiuno.cxx
index a1032dc..4d24c0d 100644
--- a/sc/source/ui/unoobj/dapiuno.cxx
+++ b/sc/source/ui/unoobj/dapiuno.cxx
@@ -2097,7 +2097,7 @@ void ScDataPilotFieldObj::setOrientation(DataPilotFieldOrientation eNew)
                     if ( pOneDim->GetOrientation() == DataPilotFieldOrientation_HIDDEN )
                         pNewDim = pOneDim;      // use this one
                     else
-                        ++nFound;               // count existing non-hidden occurences
+                        ++nFound;               // count existing non-hidden occurrences
                 }
             }
 
@@ -2952,7 +2952,7 @@ void SAL_CALL ScDataPilotFieldGroupsObj::insertByName( const OUString& rName, co
     if( !lclExtractGroupMembers( aMembers, rElement ) )
         throw IllegalArgumentException();
 
-    // create the new entry if no error has been occured
+    // create the new entry if no error has been occurred
     maGroups.resize( maGroups.size() + 1 );
     ScFieldGroup& rGroup = maGroups.back();
     rGroup.maName = rName;
diff --git a/sc/source/ui/unoobj/nameuno.cxx b/sc/source/ui/unoobj/nameuno.cxx
index d85f24f..e890d24 100644
--- a/sc/source/ui/unoobj/nameuno.cxx
+++ b/sc/source/ui/unoobj/nameuno.cxx
@@ -218,7 +218,7 @@ void SAL_CALL ScNamedRangeObj::setName( const rtl::OUString& aNewName )
     // GRAM_PODF_A1 for API compatibility.
     Modify_Impl( &aNewStr, NULL, NULL, NULL, NULL,formula::FormulaGrammar::GRAM_PODF_A1 );
 
-    if ( aName != aNewStr )					// some error occured...
+    if ( aName != aNewStr )					// some error occurred...
         throw uno::RuntimeException();		// no other exceptions specified
 }
 
diff --git a/sc/source/ui/unoobj/viewuno.cxx b/sc/source/ui/unoobj/viewuno.cxx
index 2144f11..bfdef84 100644
--- a/sc/source/ui/unoobj/viewuno.cxx
+++ b/sc/source/ui/unoobj/viewuno.cxx
@@ -469,7 +469,7 @@ private:
     ScTabViewObj* pViewObj;
     uno::Reference< script::vba::XVBAEventProcessor > xVbaEventsHelper;
     sal_Bool bDelaySelectionEvent;
-    sal_Bool bSelectionChangeOccured;
+    sal_Bool bSelectionChangeOccurred;
 
     void fireSelectionChangeEvent();
 
@@ -487,7 +487,7 @@ public:
 };
 
 ScTabViewEventListener::ScTabViewEventListener(ScTabViewObj* pObj, uno::Reference< script::vba::XVBAEventProcessor >& rVbaEventsHelper):
-    pViewObj( pObj ),xVbaEventsHelper( rVbaEventsHelper ), bDelaySelectionEvent( sal_False ), bSelectionChangeOccured( sal_False )
+    pViewObj( pObj ),xVbaEventsHelper( rVbaEventsHelper ), bDelaySelectionEvent( sal_False ), bSelectionChangeOccurred( sal_False )
 {
 }
 
@@ -514,14 +514,14 @@ void ScTabViewEventListener::fireSelectionChangeEvent()
                 }
     }
     bDelaySelectionEvent = sal_False;
-    bSelectionChangeOccured = sal_False;
+    bSelectionChangeOccurred = sal_False;
 }
 
 sal_Bool SAL_CALL ScTabViewEventListener::mousePressed( const awt::EnhancedMouseEvent& e ) throw (uno::RuntimeException)
 {
     // Delay to fire the selection change event if clicking the left mouse button to do selection.
     bDelaySelectionEvent = ( e.Buttons == ::com::sun::star::awt::MouseButton::RIGHT ) ? sal_False : sal_True;
-    bSelectionChangeOccured = sal_False;
+    bSelectionChangeOccurred = sal_False;
 
     // ScTabViewObj::MousePressed should handle process BeforeDoubleClick and BeforeRightClick events
     return sal_True;
@@ -529,7 +529,7 @@ sal_Bool SAL_CALL ScTabViewEventListener::mousePressed( const awt::EnhancedMouse
 
 sal_Bool SAL_CALL ScTabViewEventListener::mouseReleased( const awt::EnhancedMouseEvent&/*e*/) throw (uno::RuntimeException)
 {
-    if ( bSelectionChangeOccured )
+    if ( bSelectionChangeOccurred )
         fireSelectionChangeEvent();
     return sal_True;
 }
@@ -542,7 +542,7 @@ void SAL_CALL ScTabViewEventListener::selectionChanged( const lang::EventObject&
     }
     else
     {
-        bSelectionChangeOccured = sal_True;
+        bSelectionChangeOccurred = sal_True;
     }
 }
 


More information about the Libreoffice-commits mailing list
diff --git a/sc/source/core/tool/compiler.cxx b/sc/source/core/tool/compiler.cxx
index e5eb562..8171d23 100644
--- a/sc/source/core/tool/compiler.cxx
+++ b/sc/source/core/tool/compiler.cxx
@@ -3140,10 +3140,10 @@ BOOL ScCompiler::IsColRowName( const String& rName )
         ScAutoNameCache* pNameCache = pDoc->GetAutoNameCache();
         if ( pNameCache )
         {
             //  #b6355215# use GetNameOccurences to collect all positions of aName on the sheet
             //  (only once), similar to the outer part of the loop in the "else" branch.
 
-            const ScAutoNameAddresses& rAddresses = pNameCache->GetNameOccurences( aName, aPos.Tab() );
+            const ScAutoNameAddresses& rAddresses = pNameCache->GetNameOccurrences( aName, aPos.Tab() );
 
             //  Loop through the found positions, similar to the inner part of the loop in the "else" branch.
             //  The order of addresses in the vector is the same as from ScCellIterator.
@@ -3140,10 +3140,10 @@ BOOL ScCompiler::IsColRowName( const String& rName )
         if ( pNameCache )
         {
-            //  #b6355215# use GetNameOccurences to collect all positions of aName on the sheet
+            //  #b6355215# use GetNameOccurrences to collect all positions of aName on the sheet
             //  (only once), similar to the outer part of the loop in the "else" branch.
 